import numpy
import matplotlib.pyplot as pl

numpy.seterr(divide='ignore', invalid='ignore')


def planoFase(n, x0, xf, ejex, y0, yf, ejey, ecuacion, *args):
    x = numpy.linspace(x0, xf, n)
    y = numpy.linspace(y0, yf, n)
    xx, yy = numpy.meshgrid(x, y)
    
    uu, vv = ecuacion(0, (xx, yy), *args)
    norm = numpy.sqrt(uu**2 + vv**2)
    uu = uu / norm
    vv = vv / norm
    pl.quiver(xx, yy, uu, vv, norm)
    pl.xlabel(ejex)
    pl.ylabel(ejey)
    pl.show()


def camposPendiente(n, t0, tf, ejex, y0, yf, ejey, ecuacion, *args):
    t = numpy.linspace(t0, tf, n)
    y = numpy.linspace(y0, yf, n)

    Y, T = numpy.meshgrid(y, t)
    u = 1
    v = ecuacion(T, Y, *args)
    normal = numpy.sqrt(u ** 2 + v ** 2)
    U = u / normal
    V = v / normal

    pl.quiver(T, Y, U, V, normal)
    pl.xlabel(ejex)
    pl.ylabel(ejey)	
    pl.show()


def euler(t0, tf, presente, ecuacion, intervalo, *args):

    futuros = []
    tiempos = []
    while True:
        if (t0 + intervalo) > tf:
            intervalo = tf - t0
        pendiente = ecuacion(t0, presente, *args)
        presente = presente + pendiente * intervalo
        futuros.append(presente)
        tiempos.append(t0)
        t0 += intervalo
        if t0 >= tf:
            break
    futuros = numpy.array(futuros)
    tiempos = numpy.array(tiempos)
    return futuros, tiempos
